@@ -6,15 +6,13 @@ use Lingua::KO::Munja ':all';
 binmode STDOUT, ":utf8";
 my $k = parse_kanjidic ('/home/ben/data/edrdg/kanjidic');
 my @o = kanjidic_order ($k);
-my $max = 100;
+my $max = 10;
 for my $kanji (@o[0..$max]) {
     my $entry = $k->{$kanji};
     my $korean = $entry->{W};
     if (! $korean) {
 	next;
     }
-    for my $w (@$korean) {
-	my $hangul = roman2hangul ($w);
-	print "$kanji $hangul\n";
-    }
+    my @hangul = map {roman2hangul ($_)} @$korean;
+    print "$kanji: @hangul\n";
 }
